/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EasyBeansBean.java 1121 2006-09-27 08:51:06Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.api.bean;

import org.objectweb.easybeans.api.Factory;
import org.objectweb.easybeans.api.bean.lifecycle.EasyBeansLifeCycle;
import org.objectweb.easybeans.api.container.EZBEJBContext;
import org.objectweb.easybeans.api.injection.EasyBeansInjection;

/**
 * Defines the interface of a bean.
 * @author Florent Benoit
 */
public interface EasyBeansBean extends EasyBeansLifeCycle, EasyBeansInjection {

    /**
     * Gets the factory associated to this bean.
     * @return bean's factory
     */
    Factory getEasyBeansFactory();

    /**
     * Defines the factory associated to this bean.
     * @param easyBeansFactory the EasyBeans factory that manages this bean.
     */
    void setEasyBeansFactory(Factory easyBeansFactory);

    /**
     * Gets the EJB context associated to this bean.
     * @return EJB context
     */
    EZBEJBContext getEasyBeansContext();

    /**
     * Defines the EJB context associated to this bean.
     * @param beanContext the session context associated to this bean.
     */
    void setEasyBeansContext(EZBEJBContext beanContext);

}
