/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JContainer3Identifier.java 988 2006-07-31 11:12:59Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.container.management;

import org.objectweb.easybeans.api.EZBContainer;
import org.objectweb.easybeans.api.EZBServer;
import org.objectweb.easybeans.jmx.MBeansException;
import org.objectweb.easybeans.jmx.MBeansHelper;
import org.objectweb.easybeans.jsr77.JSR77ManagementIdentifier;

/**
 * Generates an ObjectName for an EZBContainer MBean.
 *
 * @author Guillaume Sauthier
 */
public class JContainer3Identifier extends
        JSR77ManagementIdentifier<EZBContainer> {

    /**
     * JMX MBean Type.
     */
    private static final String TYPE = "EJBModule";

    /**
     * {@inheritDoc}
     */
    public String getAdditionnalProperties(final EZBContainer instance) {
        StringBuilder sb = new StringBuilder();
        // J2EEServer=?
        EZBServer server = instance.getConfiguration().getEZBServer();
        String parent = null;
        try {
            parent = MBeansHelper.getInstance().getObjectName(server);
            sb.append(getParentNameProperty(parent));

            // TODO Add inherited properties ...
        } catch (MBeansException e) {
            getLogger().warn("Cannot retrieve parent ObjectName for ''{0}''", sb);
        }

        return sb.toString();
    }

    /**
     * {@inheritDoc}
     */
    public String getNamePropertyValue(final EZBContainer instance) {
        return instance.getName().replace(":", "|");
    }

    /**
     * {@inheritDoc}
     */
    public String getTypeValue() {
        return TYPE;
    }

}
