/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JSR77ManagementIdentifier.java 643 2006-06-13 11:44:43Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.jsr77;

import java.util.Hashtable;
import java.util.Iterator;

import javax.management.MalformedObjectNameException;
import javax.management.ObjectName;

import org.objectweb.easybeans.api.jmx.EZBManagementIdentifier;
import org.objectweb.easybeans.log.JLog;
import org.objectweb.easybeans.log.JLogFactory;

/**
 * Specialized {@link EZBManagementIdentifier} for JSR77 MBeans.
 * @author Guillaume Sauthier
 *
 * @param <T> Managed Type
 */
public abstract class JSR77ManagementIdentifier<T> implements EZBManagementIdentifier<T> {

    /**
     * Logger.
     */
    private static JLog logger = JLogFactory.getLog(JSR77ManagementIdentifier.class);

    /**
     * Empty default constructor.
     */
    protected JSR77ManagementIdentifier() { }

    /**
     * @param name base ObjectName
     * @return Returns a String that contains "inherited" properties from
     *         parent's ObjectName
     */
    protected static String getInheritedPropertiesAsString(final ObjectName name) {
        Hashtable table = (Hashtable) name.getKeyPropertyList().clone();
        // we remove some attributes from the ObjectName
        table.remove("j2eeType");
        table.remove("type");
        table.remove("subtype");
        table.remove("name");
        StringBuffer sb = new StringBuffer();
        for (Iterator i = table.keySet().iterator(); i.hasNext();) {
            String key = (String) i.next();
            sb.append(key + "=" + table.get(key) + ",");
        }
        if (sb.length() > 1) {
            // remove the trailing comma
            sb.setLength(sb.length() - 1);
        }
        return sb.toString();
    }

    /**
     * @param parentObjectName Parent ObjectName.
     * @return Returns the couple j2eetype=name of the parent ObjectName.
     */
    protected static String getParentNameProperty(final String parentObjectName) {
        ObjectName on = null;
        try {
            on = ObjectName.getInstance(parentObjectName);
        } catch (MalformedObjectNameException e) {
            // TODO Add a log statement
            return "";
        } catch (NullPointerException e) {
            // TODO Add a log statement
            return "";
        }

        String type = on.getKeyProperty("j2eeType");
        String name = on.getKeyProperty("name");

        return type + "=" + name;
    }

    /**
     * {@inheritDoc}
     */
    public String getDomain() {
        // TODO Should be configurable
        return "";
    }

    /**
     * {@inheritDoc}
     */
    public String getTypeName() {
        return "j2eeType";
    }

    /**
     * {@inheritDoc}
     */
    public String getTypeProperty() {
        // TODO Move in an AbstractManagementIdentifier
        return getTypeName() + "=" + getTypeValue();
    }

    /**
     * @return the logger
     */
    public static final JLog getLogger() {
        return logger;
    }

}
