/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ResolverHelper.java 1226 2006-11-26 18:33:36Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.deployment.annotations.helper;

import org.objectweb.easybeans.deployment.annotations.exceptions.ResolverException;
import org.objectweb.easybeans.deployment.annotations.helper.bean.BusinessMethodResolver;
import org.objectweb.easybeans.deployment.annotations.helper.bean.EJB21Finder;
import org.objectweb.easybeans.deployment.annotations.helper.bean.InheritanceInterfacesHelper;
import org.objectweb.easybeans.deployment.annotations.helper.bean.InheritanceMethodResolver;
import org.objectweb.easybeans.deployment.annotations.helper.bean.InterceptorsClassResolver;
import org.objectweb.easybeans.deployment.annotations.helper.bean.InterfaceAnnotatedHelper;
import org.objectweb.easybeans.deployment.annotations.helper.bean.SecurityResolver;
import org.objectweb.easybeans.deployment.annotations.helper.bean.SessionBeanHelper;
import org.objectweb.easybeans.deployment.annotations.helper.bean.TransactionResolver;
import org.objectweb.easybeans.deployment.annotations.helper.bean.mdb.MDBListenerBusinessMethodResolver;
import org.objectweb.easybeans.deployment.annotations.metadata.ClassAnnotationMetadata;
import org.objectweb.easybeans.deployment.annotations.metadata.EjbJarAnnotationMetadata;

/**
 * This class handle some steps that need to be done after the meta-data
 * generation.
 * @author Florent Benoit
 */
public final class ResolverHelper {

    /**
     * Helper class, no public constructor.
     */
    private ResolverHelper() {

    }

    /**
     * The helper will analyze datas of a given EjbJarAnnotationMetadata object.
     * @param ejbJarAnnotationMetadata object to analyze
     * @throws ResolverException if one of resolver fails
     */
    public static void resolve(final EjbJarAnnotationMetadata ejbJarAnnotationMetadata) throws ResolverException {

        // Found each bean class
        for (ClassAnnotationMetadata classMetaData : ejbJarAnnotationMetadata.getClassAnnotationMetadataCollection()) {

            if (classMetaData.isBean()) {

                // Inheritance on interfaces
                InheritanceInterfacesHelper.resolve(classMetaData);
                InterfaceAnnotatedHelper.resolve(classMetaData);
                InheritanceMethodResolver.resolve(classMetaData);

                // Analyze EJB 2.1x home/localhome for finding interface used
                EJB21Finder.resolve(classMetaData);

                // Find business method
                if (classMetaData.isSession()) {
                    BusinessMethodResolver.resolve(classMetaData);
                } else if (classMetaData.isMdb()) {
                    MDBListenerBusinessMethodResolver.resolve(classMetaData);
                }

                // Security
                SecurityResolver.resolve(classMetaData);

                // Transaction
                TransactionResolver.resolve(classMetaData);

                // Interceptors
                InterceptorsClassResolver.resolve(classMetaData);

            }

            // for each bean, call sub helper
            if (classMetaData.isSession()) {
                SessionBeanHelper.resolve(classMetaData);
            }
        }
    }
}
