/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestWrongSpecification.java 978 2006-07-28 13:19:14Z studzine $
 * --------------------------------------------------------------------------
 */
package org.objectweb.easybeans.tests.interceptors.business.stateless.containermanaged;

import static org.objectweb.easybeans.tests.common.enhancer.ClassesEnhancer.EXT_CLASS;
import static org.objectweb.easybeans.tests.common.enhancer.ClassesEnhancer.enhanceNewClassLoader;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import org.objectweb.easybeans.deployment.annotations.exceptions.InterceptorsValidationException;
import org.objectweb.easybeans.tests.common.ejbs.base.ItfOneMethod00;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.wrongspecification.ItfWithInterceptor;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.wrongspecification.SLSBFinalExternalInterceptor;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.wrongspecification.SLSBFinalInternalInterceptor;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.wrongspecification.SLSBItfWithInterceptor;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.wrongspecification.SLSBStaticExternalInterceptor;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.wrongspecification.SLSBStaticInternalInterceptor;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.wrongspecification.SLSBTwoArInvokeExternalInterceptor;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.wrongspecification.SLSBTwoAroundInvokeError;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.wrongspecification.SLSBVoidExternalInterceptor;
import org.objectweb.easybeans.tests.common.ejbs.stateless.containermanaged.wrongspecification.SLSBWithArgsInterceptor;
import org.objectweb.easybeans.tests.common.enhancer.ClassesEnhancer.TYPE;
import org.objectweb.easybeans.tests.common.interceptors.business.wrongspecification.ArgsConstructorInterceptor;
import org.objectweb.easybeans.tests.common.interceptors.business.wrongspecification.FinalMethodInterceptor;
import org.objectweb.easybeans.tests.common.interceptors.business.wrongspecification.StaticMethodInterceptor;
import org.objectweb.easybeans.tests.common.interceptors.business.wrongspecification.TwoAroundInvokeInterceptor;
import org.objectweb.easybeans.tests.common.interceptors.business.wrongspecification.VoidInterceptor;
import org.testng.annotations.Test;


/**
 * These tests verify business interceptors that were developed without
 * following the JSR 220 spec.
 * @reference JSR 220 - EJB 3.0 Core - 12
 * @author Eduardo Studzinski Estima de Castro
 * @author Gisele Pinheiro Souza
 */
public class TestWrongSpecification {

   /**
     * This test should cause an enhancer exception. Verifies if an interceptor
     * class with two &#64;AroundInvoke doesn't compile.
     * @input -
     * @output -
     * @throws Exception if there is an enhancer exception.
     */
    @Test(groups = {"withWrongSpecification"}, expectedExceptions = InterceptorsValidationException.class)
    public void testWrongSpec00() throws Exception {
        List<String> lstFiles = new ArrayList<String>();

        lstFiles.add(ItfOneMethod00.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(SLSBTwoArInvokeExternalInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(TwoAroundInvokeInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);
        enhanceNewClassLoader(lstFiles, TYPE.INTERCEPTOR);
    }

    /**
     * Verifies if an interceptor class with args doesn't compile.
     * @input -
     * @output -
     * @throws Exception if there is an enhancer exception.
     */
    @Test(groups = {"withWrongSpecification"}, expectedExceptions = InterceptorsValidationException.class)
    public void testWrongSpec01() throws Exception {
        List<String> lstFiles = new ArrayList<String>();

        lstFiles.add(SLSBWithArgsInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(ItfOneMethod00.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(ArgsConstructorInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);
        enhanceNewClassLoader(lstFiles, TYPE.INTERCEPTOR);
    }

    /**
     * This test should cause an enhancer exception. Verifies if a bean class
     * with two &#64;AroundInvoke doesn't compile.
     * @input -
     * @output -
     * @throws Exception if there is an enhancer exception.
     */
    @Test(groups = {"withWrongSpecification"}, expectedExceptions = InterceptorsValidationException.class)
    public void testWrongSpec02() throws Exception {
        List<String> lstFiles = new ArrayList<String>();

        lstFiles.add(SLSBTwoAroundInvokeError.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(ItfOneMethod00.class.getName().replace(".", File.separator) + EXT_CLASS);
        enhanceNewClassLoader(lstFiles, TYPE.INTERCEPTOR);
    }

    /**
     * This test should cause an enhancer exception. Verifies if an interceptor
     * that the return type is void doesn't compile.
     * @input -
     * @output -
     * @throws Exception if there is an enhancer exception.
     */
    @Test(groups = {"withWrongSpecification"}, expectedExceptions = InterceptorsValidationException.class)
    public void testWrongSpec03() throws Exception {
        List<String> lstFiles = new ArrayList<String>();

        lstFiles.add(SLSBVoidExternalInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(ItfOneMethod00.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(VoidInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);

        enhanceNewClassLoader(lstFiles, TYPE.INTERCEPTOR);


    }

    /**
     * Verifies if an interceptor class with a static method modifier compile.
     * @input -
     * @output -
     * @throws Exception if there is an enhancer exception.
     */
    @Test(groups = {"withWrongSpecification"}, expectedExceptions = InterceptorsValidationException.class)
      public void testWrongSpec04() throws Exception {
        List<String> lstFiles = new ArrayList<String>();

        lstFiles.add(SLSBStaticExternalInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(ItfOneMethod00.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(StaticMethodInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);
        enhanceNewClassLoader(lstFiles, TYPE.INTERCEPTOR);
    }

    /**
     * Verifies if an interceptor class with a final method modifier compile.
     * @input -
     * @output -
     * @throws Exception if there is an enhancer exception.
     */
    @Test(groups = {"withWrongSpecification"}, expectedExceptions = InterceptorsValidationException.class)
    public void testWrongSpec05() throws Exception {
        List<String> lstFiles = new ArrayList<String>();

        lstFiles.add(SLSBFinalExternalInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(ItfOneMethod00.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(FinalMethodInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);

        enhanceNewClassLoader(lstFiles, TYPE.INTERCEPTOR);
    }

    /**
     * This method should cause an exception. Verifies if an
     * &#64;AroundInvoke declared into an interface compiles.
     * @input -
     * @output -
     * @throws Exception if there is an enhancer exception.
     */
    @Test(groups = {"withWrongSpecification"}, expectedExceptions = InterceptorsValidationException.class)
    public void testWrongSpec06() throws Exception {
        List<String> lstFiles = new ArrayList<String>();

        lstFiles.add(ItfWithInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(SLSBItfWithInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);
        enhanceNewClassLoader(lstFiles, TYPE.INTERCEPTOR);
    }

    /**
     * Verifies if a bean class with a static interceptor method compiles.
     * @input -
     * @output -
     * @throws Exception if there is an enhancer exception.
     */
    @Test(groups = {"withWrongSpecification"}, expectedExceptions = InterceptorsValidationException.class)
    public void testWrongSpec07() throws Exception {
        List<String> lstFiles = new ArrayList<String>();

        lstFiles.add(SLSBStaticInternalInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(ItfOneMethod00.class.getName().replace(".", File.separator) + EXT_CLASS);
        enhanceNewClassLoader(lstFiles, TYPE.INTERCEPTOR);
    }

    /**
     * Verifies if a bean class with a final interceptor method compiles.
     * @input -
     * @output -
     * @throws Exception if there is an enhancer exception.
     */
    @Test(groups = {"withWrongSpecification"}, expectedExceptions = InterceptorsValidationException.class)
    public void testWrongSpec08() throws Exception {
        List<String> lstFiles = new ArrayList<String>();

        lstFiles.add(SLSBFinalInternalInterceptor.class.getName().replace(".", File.separator) + EXT_CLASS);
        lstFiles.add(ItfOneMethod00.class.getName().replace(".", File.separator) + EXT_CLASS);
        enhanceNewClassLoader(lstFiles, TYPE.INTERCEPTOR);
    }
}
